@@ -417,7 +417,7 @@ pango_x_font_new (PangoFontMap *fontmap, const char *spec, int size)
   result = (PangoXFont *)g_type_create_instance (PANGO_TYPE_X_FONT);
   
   result->fontmap = fontmap;
-  g_object_ref (G_OBJECT (fontmap));
+  g_object_ref (fontmap);
   result->display = pango_x_fontmap_get_display (fontmap);
 
   result->fonts = g_strsplit(spec, ",", -1);
@@ -1086,7 +1086,8 @@ pango_x_insert_subfont (PangoFont *font, const char *xlfd)
  * @subfont_charsets: location to store a pointer to an array of subfont IDs for each found subfont;
  *               the result must be freed using g_free().
  * 
- * Lists the subfonts of a given font.
+ * Lists the subfonts of a given font. The result is ordered first by charset,
+ * and then within each charset, by the order of fonts in the font specification.
  *
  * Return value: length of the arrays stored in @subfont_ids and 
  * @subfont_charsets.
@@ -1164,8 +1165,8 @@ pango_x_list_subfonts (PangoFont        *font,
 
   n_subfonts = 0;
 
-  for (i=0; i<xfont->n_fonts; i++)
-    for (j=0; j<n_charsets; j++)
+  for (j=0; j<n_charsets; j++)
+    for (i=0; i<xfont->n_fonts; i++)
       if (subfont_lists[j][i])
 	{
 	  (*subfont_ids)[n_subfonts] = subfont_lists[j][i];
@@ -1322,7 +1323,7 @@ pango_x_font_finalize (GObject *object)
   if (xfont->xface)
     pango_x_face_remove (xfont->xface, (PangoFont *)xfont);
 
-  g_object_unref (G_OBJECT (xfont->fontmap));
+  g_object_unref (xfont->fontmap);
 
   g_strfreev (xfont->fonts);
 
